jactorch.transforms.vision.functional
=====================================

.. automodule:: jactorch.transforms.vision.functional

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   bbox
   coor
   image









